# Changelog

We document all notable changes to this project in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.5]

### Build

* Switch to GitHub Actions.

## [0.1.4]

### Fixed

* Handle JWT auth as basic auth when provided in the metadata api url.

## [0.1.3]

### Changed

* Automatically configure logging in Relay environments.
* Provide relevant log messages for setting outputs.

## [0.1.2]

### Added

* Add trigger/event key handling.

## [0.1.1]

### Changed

* Synchronize versions for new upload to PyPI.

## [0.1.0]

### Added

* Initial release.

[Unreleased]: https://github.com/puppetlabs/relay-sdk-python/compare/v0.1.5...HEAD
[0.1.5]: https://github.com/puppetlabs/relay-sdk-python/compare/v0.1.4...v0.1.5
[0.1.4]: https://github.com/puppetlabs/relay-sdk-python/compare/v0.1.3...v0.1.4
[0.1.3]: https://github.com/puppetlabs/relay-sdk-python/compare/v0.1.2...v0.1.3
[0.1.2]: https://github.com/puppetlabs/relay-sdk-python/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/puppetlabs/relay-sdk-python/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/puppetlabs/relay-sdk-python/compare/775de66c45128d999013fa1143398e98dbd071c7...v0.1.0
